# Copyright 2024 Garena Online Private Limited
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from oat.oracles.gpt import GPTJudgeOracle
from oat.oracles.gsm8k import GSM8KOracle
from oat.oracles.pair import PairRMOracle
from oat.oracles.remote.client import RemoteRMOracle


def get_cls(model_name: str):
    if "pairrm" in model_name.lower():
        return PairRMOracle
    if "gpt" in model_name.lower():
        return GPTJudgeOracle
    if "remote" in model_name.lower():
        return RemoteRMOracle
    if "gsm8k" == model_name.lower():
        return GSM8KOracle
    # Return None if specified oracle is not implemented in oat;
    # in this case users need to define their own oracle.
    return None
